'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

const bcrypt = require('bcryptjs');
const db = require('./dynamo');
const mapAttributes = require('./mapAttributes');

class Hash {
  constructor({
    password,
    emailAddress,
    saltWorkFactor = 10
  }) {
    this.password = password;
    this.emailAddress = emailAddress;
    this.saltWorkFactor = saltWorkFactor;
  }

  create() {
    var _this = this;

    return _asyncToGenerator(function* () {
      const salt = yield bcrypt.genSalt(_this.saltWorkFactor);
      return bcrypt.hash(_this.password, salt);
    })();
  }

  verify() {
    var _this2 = this;

    return _asyncToGenerator(function* () {
      const users = yield _this2.getUserByEmail();
      const result = yield bcrypt.compare(_this2.password, users[0].password);
      return { user: users[0], result };
    })();
  }

  getUserByEmail() {
    const params = _extends({
      TableName: 'users'
    }, mapAttributes({ emailAddress: this.emailAddress }), {
      FilterExpression: '#emailAddress = :emailAddress'
    });

    return db.scan(params);
  }
}

module.exports = Hash;