const bcrypt = require('bcryptjs')
const db = require('./dynamo')
const mapAttributes = require('./mapAttributes')

class Hash {
  constructor({ 
    password, 
    emailAddress,
    saltWorkFactor = 10
  }) {
    this.password = password
    this.emailAddress = emailAddress
    this.saltWorkFactor = saltWorkFactor
  }

  async create() {
    const salt = await bcrypt.genSalt(this.saltWorkFactor)
    return bcrypt.hash(this.password, salt)
  }

  async verify() {
    const users = await this.getUserByEmail()
    const result = await bcrypt.compare(this.password, users[0].password)
    return { user: users[0], result }
  }

  getUserByEmail() {
    const params = {
      TableName: 'users',
      ...mapAttributes({ emailAddress: this.emailAddress }),
      FilterExpression: '#emailAddress = :emailAddress',
    }

    return db.scan(params)
  }
}

module.exports = Hash

